# Aegis Security & Compliance Prevention Policies - Terraform

<div style="margin-left:auto;margin-right:auto;text-align:center">
  <img src="https://d27ntvnf4x6xeh.cloudfront.net/aegis-logo-dark.png?Expires=1640995200&Signature=l7aAlFW-PajnXTuIZ~k1u6SsOklglcgpboJ5i93oWuq8VM1HbXL4fzmHw6ekcotxbLiifVrH79jRrhhGflTIJjk1UV8-TUODbUVw6sZDcXB959N3gggTS9mbMtmPliScmfY~V5kPrDz96hwukhhi0mUtodeLgsKgoDvsZ4yuFXDQoFsT7eS-~sPp6v2cEv3eqEwO3K-psa~tUng9fiEHBuZCrvg6I4hsKDLkvvfn1g137dsLr7jUIEYO7O0FPh1byuPc1Z2IVvg1JvSD3mIDrzZ5njwX4H33QKdHXJOI~dbfkRHzARcoJVFUVRyIXpvkL6F4qy74Fmoni6aTfX4tvw__&Key-Pair-Id=K3PCIP3D5XG2R2" width="258" height="300">
</div>



[[_TOC_]]

## Policy: [Athena Hardening](athena.rego)

### AWS Resources in Scope

- AWS Athena Database

### Policy Requirements

- Results Encryption Enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/aws-athena-workgroup-query-result-not-encrypted)
  - Any encryption type will satisfy the rule.

## Policy: [Glue Hardening](iam.rego)

### AWS Resources in Scope

- AWS IAM Role Policy

### Policy Requirements

- IAM entity shuold not be allowed to update glue dev endpoint - [Additional information](https://docs.securestate.vmware.com/rule-docs/aws-iam-glue-update-dev-endpoint)
- IAM entity shuold not be allowed to create glue dev endpoint - [Additional information](https://docs.securestate.vmware.com/rule-docs/aws-iam-glue-create-dev-endpoint)

## Policy: [DynamoDB Hardening](dynamodb.rego)

### AWS Resources in Scope

- AWS Dynamodb Table

### Policy Requirements

- Server-Side Encryption Enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/dynamodb-table-encryption)
  - Warning when using aws managed or owned CMK for encryption
- Point in Time Recovery Enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/dynamodb-table-backup-and-pitr)

## Policy: [EBS Hardening](ebs.rego)

### AWS Resources in Scope

- EBS volume

### Policy Requirements

- EBS volume encryption enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/ec2-ebs-volume-not-encrypted)

## Policy: [EC2 Hardening](ec2_ebs.rego)

### AWS Resources in Scope

- EC2 instances

### Policy Requirements

- root volume encryption enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/ec2-ebs-volume-not-encrypted)

## Policy: [Elasticsearch Hardening](es.rego)

### AWS Resources in Scope

- Elasticsearch Domains

### Policy Requirements

- Encryption at Rest is enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/elasticsearch-encryption-at-rest-enabled)
  - Instance type supports the use of encryption at rest
- Node to Node Encryption is enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/elasticsearch-node-to-node-encryption-enabled)
- Elasticsearch must reside within a VPC

## Policy: [KMS Hardening](kms.rego)

### AWS Resources in Scope

- AWS KMS Key

### Policy Requirements

- Key Rotation is enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/kms-key-rotates)

## Policy: [Lambda Hardening](lambda.rego)

### AWS Resources in Scope

- AWS Lambda Function

### Policy Requirements

- Lambda must reside within VPC
- Warning message on using aws default encryption for lambda environment variables.

## Policy: [S3 Hardening](s3.rego)

### AWS Resources in Scope

- AWS S3 Bucket

### Policy Requirements

- Server-Side Encryption Enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/s3-bucket-not-encrypted)
  - Minimum SSE: aws:kms (can additionally be CMK), AES256
- No Public ALCs:
  - Read - [Additional information](https://docs.securestate.vmware.com/rule-docs/s3-allusers-read-acp)
  - Write - [Additional information](https://docs.securestate.vmware.com/rule-docs/s3-allusers-write-acp)
- Versioning should be enabled. - [Additional information](https://docs.securestate.vmware.com/rule-docs/aws-s3-enable-mfa-delete)
- Log Buckets (ACL:`"log-delivery-write"`) with Lifecycle rules should have at least a 90-day retention policy
- Minimum required tags: [`"data_classification"`] - [Additional information](https://source.vmware.com/intranet/document/5974/I-12_2.pdf)

## Policy: [Tagging](tagging.rego)

### AWS Resources in Scope

- ALL

### Policy Requirements

- See [SBU Tagging Policy](https://confluence.carbonblack.local/display/cbengx/SBU+AWS+Tagging+Policy)

## Policy: [IAM](iam.rego)

### AWS Resources in scope

- IAM Roles
- IAM Users
- IAM Policy

### Policy Requirements

- Deny creation of IAM users
- Deny overly permissive IAM attachements to IAM role such as:

  - `arn:aws:iam::aws:policy/AdministratorAccess`
  - `arn:aws:iam::aws:policy/AmazonDynamoDBFullAccess`
  - `arn:aws:iam::aws:policy/AmazonRDSFullAccess`

- Deny IAM policy and inline policy that include overly permissive actions such as:
  - `rds:*`
  - `dynamodb:*`
  - check [denied_policy_permissions](iam.rego#5)

## Policy: [Kinesis](kinesis.rego)

### AWS Resources in Scope

- AWS Kinesis Streams

### Policy Requirements

- KMS encryption at rest must be enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/kinesis-datastream-with-no-encryption)

## Policy: [RDS](rds.rego)

### AWS Resources in Scope

- AWS RDS instances

### Policy Requirements

- RDS must be MultiAz - [Additional information](https://docs.securestate.vmware.com/rule-docs/aws-rds-db-instance-multi-az-support-is-disabled)
- Audit logging must be enabled
- RDS backup is set- [Additional information](https://docs.securestate.vmware.com/rule-docs/rds-short-backup-retention-period)
- RDS backup retention is more than 30 days - [Additional information](https://docs.securestate.vmware.com/rule-docs/rds-short-backup-retention-period)

- RDS must be encrypted - [Additional information](https://docs.securestate.vmware.com/rule-docs/rds-db-snapshot-unencrypted)
  - default KMS is allowed but not prefered
  - managed KMS is the suggested option
- RDS Replicas must be encrypted - [Additional information](https://docs.securestate.vmware.com/rule-docs/rds-db-instance-unencrypted)
- RDS deletion must be enabled - [Additional information](https://docs.securestate.vmware.com/rule-docs/aws-rds-db-cluster-deletion-protection-is-disabled/)
- RDS must not be publicly accessible - [Additional information](https://docs.securestate.vmware.com/rule-docs/rds-db-publicly-accessible/)
## Policy: [ELB](elb.rego)

### AWS Resources in Scope

- AWS ELB (Classic Loadbalancer)
- AWS ALB
- AWS NLB

### Policy Requirements

- Classic Loadbalancer: ELBSecurityPolicy-TLS-1-2-2017-01 - [Additional information](https://docs.securestate.vmware.com/rule-docs/elbv2-insecure-ssl-ciphers-and-vulnerable-ssl-protocols)
- Application Loadbalancer: ELBSecurityPolicy-FS-1-2-Res-2019-08 (if FS not supported, ELBSecurityPolicy-TLS-1-2-Ext-2018-06) - [Additional information](https://docs.securestate.vmware.com/rule-docs/elbv2-insecure-ssl-ciphers-and-vulnerable-ssl-protocols)
- Network Loadbalancer: ELBSecurityPolicy-FS-1-2-Res-2019-08 (if FS not supported, ELBSecurityPolicy-TLS-1-2-Ext-2018-06) - [Additional information](https://docs.securestate.vmware.com/rule-docs/elbv2-insecure-ssl-ciphers-and-vulnerable-ssl-protocols)

## Policy: [Security Group](security_group.rego)

### AWS Resources in Scope

- AWS Security Group
- AWS Security Group Rule

### Policy Requirements

- Security group ingress inline policy should not have 0.0.0.0/0 cidr - [Additional information](https://docs.securestate.vmware.com/rule-docs/ec2-unrestricted-traffic)
- Security group ingress rule should not have 0.0.0.0/0 cidr - [Additional information](https://docs.securestate.vmware.com/rule-docs/ec2-unrestricted-traffic)
